==> FinancialModelingPrep-Python-0.0.3.tar.gz: FinancialModelingPrep-Python-0.0.3/README.md <==
---

<div id="logo" align="center">
    <img src="https://raw.githubusercontent.com/thinh-vu/FinancialModelingPrep/main/docs/docs/assets/fmp_logo.png" alt= "logo"/>
    <img src = "https://raw.githubusercontent.com/thinh-vu/FinancialModelingPrep/main/docs/docs/assets/vnstock_logo_color.png" alt="vnstock_logo"/>
</div>

<div id="badges" align="center">
<img src="https://img.shields.io/pypi/pyversions/FinancialModelingPrep-Python?logoColor=brown&style=plastic" alt= "Version"/>
<img src="https://img.shields.io/pypi/dm/FinancialModelingPrep-Python" alt="Download Badge"/>
<img src="https://img.shields.io/github/last-commit/thinh-vu/FinancialModelingPrep-Python" alt="Commit Badge"/>
<img src="https://img.shields.io/github/license/thinh-vu/FinancialModelingPrep-Python?color=red" alt="License Badge"/>
</div>

---


# I. 🎤 Introduction

> FinancialModelingPrep is a powerful and versatile Python implementation of the [Financial Modeling Prep API](https://financialmodelingprep.com/developer/docs/), designed to simplify and enhance your financial data analysis. With this open-source wrapper, you gain seamless access to the wealth of financial data provided by Financial Modeling Prep, enabling you to make well-informed investment decisions and drive data-driven financial strategies.

# II. 📔 Quick Start Guide

For detailed usage instructions, examples, and more, visit the documentation site. Get started with the FinancialModelingPrep Python Wrapper and unlock the full potential of financial data in Python!

[![Documentation - Start Here](https://img.shields.io/badge/Documentation-Start_Here-58A1D7?style=for-the-badge&logo=fmp)](https://thinh-vu.github.io/FinancialModelingPrep)

<div id="docs" align="center">
    <img src="https://raw.githubusercontent.com/thinh-vu/FinancialModelingPrep/main/docs/docs/assets/FMP_Docs.png" alt= "logo" href="https://thinh-vu.github.io/FinancialModelingPrep/"/>
</div>

# III. 🙋‍♂️ Contact Me

You can contact me at one of my social network profiles:

<div id="badges" align="center">
  <a href="https://www.linkedin.com/in/thinh-vu">
    <img src="https://img.shields.io/badge/LinkedIn-blue?style=for-the-badge&logo=linkedin&logoColor=white" alt="LinkedIn Badge"/>
  </a>
  <a href="https://www.messenger.com/t/mr.thinh.ueh">
    <img src="https://img.shields.io/badge/Messenger-00B2FF?style=for-the-badge&logo=messenger&logoColor=white" alt="Messenger Badge"/>
  <a href="https://www.youtube.com/@learn_anything_az?sub_confirmation=1">
    <img src="https://img.shields.io/badge/YouTube-red?style=for-the-badge&logo=youtube&logoColor=white" alt="Youtube Badge"/>
  </a>
  </a>
    <a href="https://github.com/thinh-vu">
    <img src="https://img.shields.io/badge/GitHub-100000?style=for-the-badge&logo=github&logoColor=white" alt="Github Badge"/>
  </a>
</div>

# IV. License

```
Copyright (c) 2022 Thinh Vu | thinh-vu @ Github | MIT

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
```

==> FinancialModelingPrep-Python-0.0.4.tar.gz: FinancialModelingPrep-Python-0.0.4/README.md <==
<div id="logo" align="center">
    <a href="https://intelligence.financialmodelingprep.com/pricing-plans?couponCode=thinhvu&utm_source=github&utm_medium=thinhvu_repos&utm_campaign=thinhvu">
        <img src="https://raw.githubusercontent.com/thinh-vu/FinancialModelingPrep/main/docs/docs/assets/fmp_logo.png" alt="logo"/>
    </a>
    <a href="http://vnstock.site/&utm_medium=FMP_Github&utm_content=Docs_Site">
        <img src="https://raw.githubusercontent.com/thinh-vu/FinancialModelingPrep/main/docs/docs/assets/vnstock_logo_color.png" alt="vnstock_logo"/>
    </a>
</div>


<div id="badges" align="center">
<img src="https://img.shields.io/pypi/pyversions/FinancialModelingPrep-Python?logoColor=brown&style=plastic" alt= "Version"/>
<img src="https://img.shields.io/pypi/dm/FinancialModelingPrep-Python" alt="Download Badge"/>
<img src="https://img.shields.io/github/last-commit/thinh-vu/FinancialModelingPrep" alt="Commit Badge"/>
<img src="https://img.shields.io/github/license/thinh-vu/FinancialModelingPrep?color=red" alt="License Badge"/>
</div>

---

# I. 🎤 Introduction

> FinancialModelingPrep is a powerful and versatile Python implementation of the [Financial Modeling Prep API](https://intelligence.financialmodelingprep.com/pricing-plans?couponCode=thinhvu&utm_source=github&utm_medium=thinhvu_repos&utm_campaign=thinhvu), designed to simplify and enhance your financial data analysis. With this open-source wrapper, you gain seamless access to the wealth of financial data provided by Financial Modeling Prep, enabling you to make well-informed investment decisions and drive data-driven financial strategies.

# II. 📔 Quick Start Guide

For detailed usage instructions, examples, and more, visit the documentation site. Get started with the FinancialModelingPrep Python Wrapper and unlock the full potential of financial data in Python!

[![Documentation - Start Here](https://img.shields.io/badge/Documentation-Start_Here-58A1D7?style=for-the-badge&logo=fmp)](https://thinh-vu.github.io/FinancialModelingPrep)

<div id="docs" style="text-align: center;">
    <a href="https://thinh-vu.github.io/FinancialModelingPrep/">
        <img src="https://raw.githubusercontent.com/thinh-vu/FinancialModelingPrep/main/docs/docs/assets/FMP_Docs.png" alt="logo">
    </a>
</div>


# III. 🙋‍♂️ Contact Me

You can contact me at one of my social network profiles:

<div id="badges" align="center">
  <a href="https://www.linkedin.com/in/thinh-vu">
    <img src="https://img.shields.io/badge/LinkedIn-blue?style=for-the-badge&logo=linkedin&logoColor=white" alt="LinkedIn Badge"/>
  </a>
  <a href="https://www.messenger.com/t/mr.thinh.ueh">
    <img src="https://img.shields.io/badge/Messenger-00B2FF?style=for-the-badge&logo=messenger&logoColor=white" alt="Messenger Badge"/>
  <a href="https://www.youtube.com/@learn_anything_az?sub_confirmation=1">
    <img src="https://img.shields.io/badge/YouTube-red?style=for-the-badge&logo=youtube&logoColor=white" alt="Youtube Badge"/>
  </a>
  </a>
    <a href="https://github.com/thinh-vu">
    <img src="https://img.shields.io/badge/GitHub-100000?style=for-the-badge&logo=github&logoColor=white" alt="Github Badge"/>
  </a>
</div>

# IV. License

```
Copyright (c) 2023 Thinh Vu | thinh-vu @ Github | MIT

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
```
